@@ -62,6 +62,7 @@ __all__ = (
     "MinimumHealthyHostsTypeDef",
     "OnPremisesTagSetTypeDef",
     "RawStringTypeDef",
+    "RelatedDeploymentsTypeDef",
     "ResponseMetadata",
     "RevisionInfoTypeDef",
     "RevisionLocationTypeDef",
@@ -217,6 +218,7 @@ DeploymentGroupInfoTypeDef = TypedDict(
         "alarmConfiguration": "AlarmConfigurationTypeDef",
         "autoRollbackConfiguration": "AutoRollbackConfigurationTypeDef",
         "deploymentStyle": "DeploymentStyleTypeDef",
+        "outdatedInstancesStrategy": Literal["UPDATE", "IGNORE"],
         "blueGreenDeploymentConfiguration": "BlueGreenDeploymentConfigurationTypeDef",
         "loadBalancerInfo": "LoadBalancerInfoTypeDef",
         "lastSuccessfulDeployment": "LastDeploymentInfoTypeDef",
@@ -252,6 +254,7 @@ DeploymentInfoTypeDef = TypedDict(
             "autoscaling",
             "codeDeployRollback",
             "CodeDeploy",
+            "CodeDeployAutoUpdate",
             "CloudFormation",
             "CloudFormationRollback",
         ],
@@ -269,6 +272,7 @@ DeploymentInfoTypeDef = TypedDict(
         "deploymentStatusMessages": List[str],
         "computePlatform": Literal["Server", "Lambda", "ECS"],
         "externalId": str,
+        "relatedDeployments": "RelatedDeploymentsTypeDef",
     },
     total=False,
 )
@@ -559,7 +563,7 @@ LoadBalancerInfoTypeDef = TypedDict(
 
 MinimumHealthyHostsTypeDef = TypedDict(
     "MinimumHealthyHostsTypeDef",
-    {"value": int, "type": Literal["HOST_COUNT", "FLEET_PERCENT"]},
+    {"type": Literal["HOST_COUNT", "FLEET_PERCENT"], "value": int},
     total=False,
 )
 
@@ -569,6 +573,15 @@ OnPremisesTagSetTypeDef = TypedDict(
 
 RawStringTypeDef = TypedDict("RawStringTypeDef", {"content": str, "sha256": str}, total=False)
 
+RelatedDeploymentsTypeDef = TypedDict(
+    "RelatedDeploymentsTypeDef",
+    {
+        "autoUpdateOutdatedInstancesRootDeploymentId": str,
+        "autoUpdateOutdatedInstancesDeploymentIds": List[str],
+    },
+    total=False,
+)
+
 ResponseMetadata = TypedDict(
     "ResponseMetadata",
     {
